@@ -1,6 +1,5 @@
 package org.acme.infinispan.client;
 
-import io.quarkus.test.common.QuarkusTestResource;
 import io.quarkus.test.junit.QuarkusTest;
 import org.junit.jupiter.api.Test;
 
@@ -8,7 +7,6 @@ import static io.restassured.RestAssured.given;
 import static org.hamcrest.CoreMatchers.is;
 
 @QuarkusTest
-@QuarkusTestResource(CacheResource.class)
 class InfinispanGreetingResourceTest {
 
     @Test
